@@ -17,3 +17,5 @@ def main():
 	Koppula Praveen Kumar
 	koppulapraveen920@gmail.com
 	 ''')
+	f=open('tempo.py','w')
+	f.close()
